GaussianSynchrotron — so_pysm_models v0.4.dev231

so_pysm_models:docs

- Index
- Modules

### Navigation

- next »
- « previous |
- so_pysm_models v0.4.dev231 »
- GaussianSynchrotron

# GaussianSynchrotron

class `so_pysm_models.` `GaussianSynchrotron`(nside, has_polarization=True, pixel_indices=None, TT_amplitude=20.0, Toffset=72.0, EE_amplitude=4.3, rTE=0.35, EtoB=0.5, alpha=-1.0, beta=-3.1, curv=0.0, nu_0=23.0, seed=None, map_dist=None)

  Bases: `pysm.models.template.Model`

  Gaussian synchrotron model

  See more details at https://so-pysm-models.readthedocs.io/en/latest/so_pysm_models/models.html

  Parameters
    nsideint

      HEALPix NSIDE of the output maps

    has_polarizationbool

      whether or not to simulate also polarization maps Default: True

    pixel_indicesndarray of ints

      Outputa partial maps given HEALPix pixel indices in RING ordering

    TT_amplitudefloat

      amplitude of synchrotron TT power spectrum (D_ell) at at the reference frequency and ell=80, in muK^2 and thermodinamic units. Default: 20 from the amplitude of PySM-s0 synchrotron model at 23GHz in the region covered by SO-SAT.

    Toffsetfloat

      offset to be applied to the temperature map in muK. Default: 72 from the mean value of the T PySM-s0 synch map at 23GHz in the region covered by SO-SAT

    EE_amplitudefloat

      same as TT_amplitude but for EE power spectrum. Default: 4.3 from the amplitude of S-PASS E-modes power spectrum at 2.3GHz in the region covered by SO-SAT, rescaled at 23GHz with a powerlaw with beta_s = -3.1

    rTEfloat

      TE correlation factor defined as: rTE = clTE/sqrt(clTT*clEE) Default: 0.35 from Planck IX 2018

    EtoBfloat

      ratio between E and B-mode amplitude. Default: 0.5 from Krachmalnicoff et al. 2018

    alphaspectral tilt of the synchrotron power spectrum (D_ell).

      Default: -1.0 from Krachmalnicoff et al. 2018

    betasynchrotron spectral index.

      Default: -3.1 from Planck 2018 IX

    curvsynchrotron curvature index.

      Default: 0.

    nu_0synchrotron reference frequency in GHz.

      Default: 23

    seedint

      seed for random realization of map Default: None

  Methods Summary

  `get_emission`(self, freqs[, weights]) | Return map in uK_RJ at given frequency or array of frequencies

  Methods Documentation

  `get_emission`(self, freqs:Unit("GHz"), weights=None) -> Unit("uK_RJ")

    Return map in uK_RJ at given frequency or array of frequencies